tkmilan
=======

.. automodule:: tkmilan

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      MODULES_VERBOSE
      varOrientation
      varEventBusEventType
      varSidSettings
      AUTO
      HORIZONTAL
      VERTICAL
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      Combobox
      ComboboxMap
      ComboboxRaw
      Entry
      LOGGING_VERBOSE
      RadioFrame
      RadioFrame_Raw
      SeparatorH
      SeparatorV
      Spinbox
      SpinboxNum
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Button
      Canvas
      Checkbox
      CheckboxFrame
      ComboboxN
      EntryMultiline
      EntryN
      EntryRaw
      FrameLabelled
      FramePaned
      FrameRadio
      FrameStateful
      FrameUnlabelled
      Label
      LabelStateful
      Listbox
      ListboxControl
      Notebook
      NotebookUniform
      Radio
      RadioFrameLabelled
      RadioFrameStateful
      RadioFrameUnlabelled
      RootWindow
      Scrolled
      ScrolledWidget
      SecondaryWindow
      Separator
      SpinboxN
      Tooltip
      Tree
      varTree
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   tkmilan.autolayout
   tkmilan.bg
   tkmilan.diagram
   tkmilan.drender
   tkmilan.exception
   tkmilan.fn
   tkmilan.mixin
   tkmilan.model
   tkmilan.parser
   tkmilan.util
   tkmilan.validation
   tkmilan.var

